replace = {
    "classs": "class",
    "forr": "for",
    "accessskey": "accesskey",
    "aria_lable": "aria-label",
    "comment": "!--",
    "aria_describedby": "aria-describedby",
    "iss": "is",
    "doctype": "!DOCTYPE HTML",
    "typee": "type",
}
